<?php
// includes/admin-page-license.php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/**
 * Renders the HTML for the License Management admin page.
 */
function minichat_license_page_html() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Get current license options
    $options = get_option(MINICHAT_LICENSE_OPTIONS_NAME, [
        'key' => '', 'status' => 'inactive', 'valid' => false, 'message' => '', 'data' => null, 'last_checked' => ''
    ]);
    $license_key = $options['key'] ?? '';
    $license_status = $options['status'] ?? 'inactive';
    $license_valid = $options['valid'] ?? false;
    $license_message = $options['message'] ?? '';
    $license_data = $options['data'] ?? null;
    $last_checked = $options['last_checked'] ?? '';

    // Get trial status
    $trial_info = minichat_get_trial_info();
    $trial_active = $trial_info['active'];
    $trial_used = $trial_info['trial_used'];
    
    // Get grace period status
    $grace_info = minichat_get_grace_period_info();
    $grace_active = $grace_info['active'];

    // Normalize domain for display
    $normalized_domain = minichat_get_normalized_domain();

    ?>
    <div class="wrap" id="minichat-license-wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        <p>Manage your Minimal Chatbot license key for this website (<?php echo esc_html($normalized_domain); ?>).</p>

        <?php if ($grace_active): ?>
        <div class="notice notice-warning" style="margin-left: 0;">
            <h3>Grace Period Active</h3>
            <p>Chatbot is currently operating in Grace Period mode due to license server connection issues.</p>
            <p><strong>Time Remaining:</strong> <?php echo esc_html($grace_info['time_remaining_human']); ?></p>
            <p><strong>Reason:</strong> <?php echo esc_html($grace_info['reason']); ?></p>
            <p>Grace period provides full functionality temporarily while server issues are being resolved. 
               The chatbot will attempt to reconnect to the license server automatically.</p>
        </div>
        <?php endif; ?>

        <?php if ($trial_active): ?>
        <div class="notice notice-info" style="margin-left: 0;">
            <h3>Trial Mode Active</h3>
            <p>You're currently using the trial version of Minimal Chatbot.</p>
            <p><strong>Time Remaining:</strong> <?php echo esc_html($trial_info['days_remaining']); ?> days 
               (expires on <?php echo esc_html(date('F j, Y', strtotime($trial_info['expires']))); ?>)</p>
            <p><strong>Limitations:</strong> Limited to <?php echo MINICHAT_MESSAGES_LIMIT_TRIAL; ?> messages per user.</p>
            <p>To continue using the chatbot without limitations after the trial period, please activate a license key below.</p>
        </div>
        <?php endif; ?>

        <div id="license-status-box" style="border: 1px solid #ccc; padding: 15px; margin-bottom: 20px; background-color: #fff; max-width: 600px; border-left-width: 4px; border-left-color: <?php echo $license_valid ? '#4caf50' : '#f44336'; ?>;">
            <h3>Current License Status</h3>
            <p>
                <strong>Status:</strong>
                <span id="license-status-text" style="font-weight: bold; color: <?php echo $license_valid ? 'green' : 'red'; ?>;">
                    <?php echo esc_html(ucfirst($license_status)); ?>
                </span>
                <?php if ($license_valid): ?>
                    <span class="dashicons dashicons-yes-alt" style="color: green;"></span>
                <?php else: ?>
                     <span class="dashicons dashicons-warning" style="color: red;"></span>
                <?php endif; ?>
            </p>
             <p id="license-message-text"><strong>Message:</strong> <?php echo esc_html($license_message); ?></p>
            <?php if (!empty($last_checked)): ?>
                <p><em>Last checked: <?php echo esc_html(wp_date(get_option('date_format') . ' ' . get_option('time_format'), strtotime($last_checked))); ?></em></p>
            <?php endif; ?>

             <?php if ($license_valid && !empty($license_data)): ?>
                <h4>License Details:</h4>
                <ul>
                    <?php if (isset($license_data['customer_name'])) echo '<li>Customer: ' . esc_html($license_data['customer_name']) . '</li>'; ?>
                    <?php if (isset($license_data['customer_email'])) echo '<li>Email: ' . esc_html($license_data['customer_email']) . '</li>'; ?>
                    <?php if (isset($license_data['expiry_date'])) echo '<li>Expires: ' . esc_html(wp_date(get_option('date_format'), strtotime($license_data['expiry_date']))) . '</li>'; ?>
                    <?php // Add other relevant fields from your license data object ?>
                </ul>
            <?php endif; ?>

            <button type="button" id="minichat-verify-license-btn" class="button">
                <span class="dashicons dashicons-update-alt" style="vertical-align: middle;"></span> Re-Check Status
            </button>
            <span id="verify-spinner" class="spinner" style="float: none; vertical-align: middle;"></span>

        </div>

        <hr>

        <h3>Enter or Update License Key</h3>
        <table class="form-table" role="presentation" style="max-width: 600px;">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="minichat-license-key-input">License Key</label>
                    </th>
                    <td>
                        <input type="text" id="minichat-license-key-input" name="minichat_license_key" value="<?php echo esc_attr($license_key); ?>" class="regular-text" placeholder="Enter your license key"/>
                         <p class="description">Enter the license key you received after purchase.</p>
                    </td>
                </tr>
            </tbody>
        </table>

        <p class="submit">
            <button type="button" id="minichat-activate-license-btn" class="button button-primary">
                 <span class="dashicons dashicons-yes" style="vertical-align: middle;"></span> Activate License
            </button>
            <span id="activate-spinner" class="spinner" style="float: none; vertical-align: middle;"></span>
        </p>

        <?php if (!$trial_active && !$trial_used): ?>
        <hr>
        <h3>Start Trial Period</h3>
        <p>No license key? You can start a 14-day trial period with limited functionality.</p>
        <p><strong>Trial includes:</strong></p>
        <ul style="list-style-type: disc; margin-left: 20px;">
            <li>Full chatbot functionality</li>
            <li>Limited to <?php echo MINICHAT_MESSAGES_LIMIT_TRIAL; ?> messages per user</li>
            <li>14 days to test before purchasing</li>
        </ul>
        <p class="submit">
            <button type="button" id="minichat-start-trial-btn" class="button button-secondary">
                <span class="dashicons dashicons-clock" style="vertical-align: middle;"></span> Start Trial Period
            </button>
            <span id="trial-spinner" class="spinner" style="float: none; vertical-align: middle;"></span>
        </p>
        <?php elseif ($trial_used && !$trial_active): ?>
        <hr>
        <div class="notice notice-warning inline">
            <p><strong>Trial period has expired or has been used on this site.</strong> Please activate a license key to continue using the chatbot.</p>
        </div>
        <?php endif; ?>

         <div id="license-ajax-message" style="margin-top: 15px;"></div>

    </div>

    <script type="text/javascript">
        jQuery(document).ready(function($) {

            var licenseWrap = $('#minichat-license-wrap');
            var activateBtn = $('#minichat-activate-license-btn');
            var verifyBtn = $('#minichat-verify-license-btn');
            var startTrialBtn = $('#minichat-start-trial-btn');
            var licenseInput = $('#minichat-license-key-input');
            var activateSpinner = $('#activate-spinner');
            var verifySpinner = $('#verify-spinner');
            var trialSpinner = $('#trial-spinner');
            var ajaxMessages = $('#license-ajax-message');
            var statusBox = $('#license-status-box');
            var statusText = $('#license-status-text');
            var messageText = $('#license-message-text');


            // Function to update status display
            function updateStatusDisplay(isValid, status, message) {
                statusText.text(status.charAt(0).toUpperCase() + status.slice(1)); // Capitalize first letter
                messageText.html('<strong>Message:</strong> ' + message); // Assumes message is already escaped

                if (isValid) {
                    statusBox.css('border-left-color', '#4caf50');
                    statusText.css('color', 'green');
                    statusText.next('.dashicons').removeClass('dashicons-warning').addClass('dashicons-yes-alt').css('color', 'green');
                } else {
                    statusBox.css('border-left-color', '#f44336');
                    statusText.css('color', 'red');
                     statusText.next('.dashicons').removeClass('dashicons-yes-alt').addClass('dashicons-warning').css('color', 'red');
                }
                 // Refresh page after update might be good to show license details if activated
                 // Or update details dynamically (more complex)
                 // For simplicity, we'll just show the message for now.
            }

             // Function to show AJAX messages
            function showAjaxMessage(message, isError) {
                ajaxMessages.removeClass('notice-success notice-error').addClass(isError ? 'notice-error' : 'notice-success').html('<p>' + message + '</p>').show();
            }


            // Activate Button Click
            activateBtn.on('click', function() {
                var licenseKey = licenseInput.val().trim();
                if (!licenseKey) {
                    showAjaxMessage('Please enter a license key.', true);
                    return;
                }

                activateSpinner.addClass('is-active');
                activateBtn.prop('disabled', true);
                ajaxMessages.hide();

                $.ajax({
                    url: ajaxurl, // WordPress AJAX URL
                    type: 'POST',
                    data: {
                        action: 'minichat_activate_license',
                        nonce: '<?php echo wp_create_nonce("minichat_license_nonce"); ?>', // Create nonce here
                        license_key: licenseKey
                    },
                    dataType: 'json',
                    success: function(response) {
                        if (response.success) {
                            showAjaxMessage('License Activated: ' + response.data.message, false);
                            // Update the displayed status based on the response
                            updateStatusDisplay(response.data.valid, response.data.status, response.data.message);
                             // Optionally reload the page to show full license details
                             setTimeout(function() {
                                 window.location.reload();
                             }, 1500);
                        } else {
                            showAjaxMessage('Activation Failed: ' + (response.data.message || 'Unknown error'), true);
                            updateStatusDisplay(false, 'error', (response.data.message || 'Activation failed'));
                        }
                    },
                    error: function(jqXHR, textStatus, errorThrown) {
                         console.error("License Activation AJAX Error:", textStatus, errorThrown);
                         showAjaxMessage('An AJAX error occurred: ' + textStatus, true);
                          updateStatusDisplay(false, 'error', 'AJAX communication error.');
                    },
                    complete: function() {
                        activateSpinner.removeClass('is-active');
                        activateBtn.prop('disabled', false);
                    }
                });
            });

            // Verify Button Click
            verifyBtn.on('click', function() {
                verifySpinner.addClass('is-active');
                verifyBtn.prop('disabled', true);
                ajaxMessages.hide();

                 $.ajax({
                    url: ajaxurl,
                    type: 'POST', // Use POST for consistency or GET if server expects GET for verify
                    data: {
                        action: 'minichat_verify_license',
                        nonce: '<?php echo wp_create_nonce("minichat_license_nonce"); ?>'
                        // License key is read from saved options on the server-side
                    },
                    dataType: 'json',
                    success: function(response) {
                        if (response.success) {
                            showAjaxMessage('Status Checked: ' + response.data.message, false);
                            updateStatusDisplay(response.data.valid, response.data.status, response.data.message);
                            setTimeout(function() {
                                window.location.reload();
                            }, 1500);
                        } else {
                            showAjaxMessage('Verification Failed: ' + (response.data.message || 'Unknown error'), true);
                            updateStatusDisplay(false, 'error', (response.data.message || 'Verification failed'));
                        }
                    },
                    error: function(jqXHR, textStatus, errorThrown) {
                         console.error("License Verification AJAX Error:", textStatus, errorThrown);
                         showAjaxMessage('An AJAX error occurred: ' + textStatus, true);
                         updateStatusDisplay(false, 'error', 'AJAX communication error.');
                    },
                    complete: function() {
                        verifySpinner.removeClass('is-active');
                        verifyBtn.prop('disabled', false);
                    }
                });
            });
            
            // Start Trial Button Click
            if (typeof startTrialBtn !== 'undefined' && startTrialBtn.length) {
                startTrialBtn.on('click', function() {
                    if (!confirm('Are you sure you want to start the trial period? This can only be used once.')) {
                        return;
                    }
                    
                    trialSpinner.addClass('is-active');
                    startTrialBtn.prop('disabled', true);
                    ajaxMessages.hide();
                    
                    $.ajax({
                        url: ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'minichat_activate_trial',
                            nonce: '<?php echo wp_create_nonce("minichat_license_nonce"); ?>'
                        },
                        dataType: 'json',
                        success: function(response) {
                            if (response.success) {
                                showAjaxMessage('Trial Period Activated: ' + response.data.message, false);
                                setTimeout(function() {
                                    window.location.reload();
                                }, 1500);
                            } else {
                                showAjaxMessage('Trial Activation Failed: ' + (response.data.message || 'Unknown error'), true);
                            }
                        },
                        error: function(jqXHR, textStatus, errorThrown) {
                            console.error("Trial Activation AJAX Error:", textStatus, errorThrown);
                            showAjaxMessage('An AJAX error occurred: ' + textStatus, true);
                        },
                        complete: function() {
                            trialSpinner.removeClass('is-active');
                            startTrialBtn.prop('disabled', false);
                        }
                    });
                });
            }

        });
    </script>
    <?php
}