<?php
/*
Plugin Name: Chatbot (V1.12.1 - Refactored + Settings Group Fix)
Description: Chatbot mit DB-Gedächtnis, Lizenzierung, UI, Feedback, Sprache, Proactive Behavior, Kontext-Awareness. AJAX/Helpers ausgelagert, Settings-Speichern korrigiert, Default-Wert korrigiert. FULL CODE.
Version: 1.12.1
Author: Robutech
*/

// Prevent direct access
if (!defined('ABSPATH')) { exit; }

// --- Constants ---
define('MINICHAT_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('MINICHAT_PLUGIN_URL', plugin_dir_url(__FILE__));
define('MINICHAT_DEBUG_LOG', true); // Keep logging enabled!
define('MINICHAT_VERSION', '1.12.1'); // Updated Version
define('MINICHAT_DB_READY_OPTION', 'minichat_db_ready_status_v1_6_2');
define('MINICHAT_ADMIN_NOTICE_TRANSIENT', 'minichat_admin_notice_db_fail_v1_6_2');
define('MINICHAT_USER_COOKIE_NAME', 'minichat_user_id');
define('MINICHAT_LICENSE_OPTIONS_NAME', 'minichat_license_options');
define('MINICHAT_LICENSE_SERVER_URL', 'https://lic.robutech.ch/api');
define('MINICHAT_PLUGIN_API_KEY', '5e98c16fcd299aa71fedf89a204af24a'); // Replace if needed
define('MINICHAT_MESSAGES_LIMIT_TRIAL', 50);
define('MINICHAT_CONTEXT_CACHE_TRANSIENT', 'minichat_context_cache_v1_11');
define('MINICHAT_CONTEXT_UPDATE_HOOK', 'minichat_update_context_cache_hook');
define('MINICHAT_DEFAULT_CACHE_LIMIT', 5000);

if (MINICHAT_DEBUG_LOG) error_log("MC[Init v" . MINICHAT_VERSION . "]: Main plugin file loaded.");

// --- Globals ---
global $wpdb;

// --- Include necessary files ---
$includes_path = MINICHAT_PLUGIN_DIR . 'includes/';
if (MINICHAT_DEBUG_LOG) error_log("MC[Init v" . MINICHAT_VERSION . "]: Including required files...");

// Include original dependencies first
$original_includes = [
    'license-handler.php',
    'admin-page-license.php',
    'admin-page-feedback.php',
    'class-minichat-users-list-table.php',
    'admin-page-status.php'
];
foreach ($original_includes as $file) {
    $file_path = $includes_path . $file;
    if (file_exists($file_path)) {
        require_once $file_path;
        if (MINICHAT_DEBUG_LOG) error_log("MC[Include]: OK {$file}");
    } else {
        $msg = "MC CRITICAL ERROR: Required include file 'includes/{$file}' not found.";
        if (MINICHAT_DEBUG_LOG) error_log($msg);
        add_action('admin_notices', function() use ($msg) { echo '<div class="notice notice-error"><p><strong>MiniChat Fatal Error:</strong><br>' . esc_html($msg) . '</p></div>'; });
        // return; // Consider stopping if critical includes fail
    }
}

// Include NEW Helper Functions file (MUST be included BEFORE ajax-handlers)
$helper_file = $includes_path . 'helper-functions.php';
if (file_exists($helper_file)) {
    require_once $helper_file;
    if (MINICHAT_DEBUG_LOG) error_log("MC[Include]: OK helper-functions.php");
} else {
    $msg = "MC CRITICAL ERROR: Required include file 'includes/helper-functions.php' not found.";
    if (MINICHAT_DEBUG_LOG) error_log($msg);
    add_action('admin_notices', function() use ($msg) { echo '<div class="notice notice-error"><p><strong>MiniChat Fatal Error:</strong><br>' . esc_html($msg) . '</p></div>'; });
    // return; // Stop if helpers are missing
}

// Include NEW AJAX Handlers file
$ajax_file = $includes_path . 'ajax-handlers.php';
if (file_exists($ajax_file)) {
    require_once $ajax_file;
     if (MINICHAT_DEBUG_LOG) error_log("MC[Include]: OK ajax-handlers.php");
} else {
    $msg = "MC CRITICAL ERROR: Required include file 'includes/ajax-handlers.php' not found.";
    if (MINICHAT_DEBUG_LOG) error_log($msg);
    add_action('admin_notices', function() use ($msg) { echo '<div class="notice notice-error"><p><strong>MiniChat Fatal Error:</strong><br>' . esc_html($msg) . '</p></div>'; });
    // return; // Stop if AJAX handlers are missing
}

if (MINICHAT_DEBUG_LOG) error_log("MC[Init v" . MINICHAT_VERSION . "]: Finished includes.");


// --- Activation / Deactivation Hooks ---
register_activation_hook(__FILE__, 'minichat_plugin_activate');
register_deactivation_hook(__FILE__, 'minichat_plugin_deactivate');
// Definition remains here as it's tied to the plugin file
function minichat_plugin_activate() {
    global $wpdb; $table_name = $wpdb->prefix.'minichat_history'; $charset_collate = $wpdb->get_charset_collate(); $db_ready_option_name = MINICHAT_DB_READY_OPTION; $notice_transient_name = MINICHAT_ADMIN_NOTICE_TRANSIENT; if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: Run hook."); delete_option($db_ready_option_name); delete_transient($notice_transient_name); $sql = "CREATE TABLE {$table_name} (id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT, user_id VARCHAR(100) NOT NULL, session_id VARCHAR(100) NOT NULL, role VARCHAR(10) NOT NULL, content TEXT NOT NULL, feedback_rating TINYINT DEFAULT NULL, feedback_text TEXT DEFAULT NULL, timestamp DATETIME DEFAULT CURRENT_TIMESTAMP NOT NULL, PRIMARY KEY (id), KEY user_idx (user_id(10)), KEY session_idx (session_id(10)), KEY feedback_rating_idx (feedback_rating)) {$charset_collate};"; require_once(ABSPATH.'wp-admin/includes/upgrade.php'); if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: Try dbDelta for: ".$table_name); $wpdb->suppress_errors(true); $delta_results=dbDelta($sql); $wpdb_last_error_delta=$wpdb->last_error; $wpdb->suppress_errors(false); if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: dbDelta results: ".print_r($delta_results,true)); if(!empty($wpdb_last_error_delta)){if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]:WARN dbDelta err: ".$wpdb_last_error_delta);} $table_exists=$wpdb->get_var($wpdb->prepare("SHOW TABLES LIKE %s",$table_name))===$table_name; $all_checks_passed=$table_exists; $final_error_details=""; if(!$table_exists){$final_error_details="Table '{$table_name}' not created/verified."; if(!empty($wpdb_last_error_delta)){$final_error_details.=" DB Delta Err: [".esc_html($wpdb_last_error_delta)."].";}} /* Add detailed column checks here if needed */ if($all_checks_passed){if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]:SUCCESS DB setup OK.");update_option($db_ready_option_name,'yes');} else{$notice_message="Failed DB setup for MiniChat ('{$table_name}'). Reason: ".($final_error_details?:"Unknown.");if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]:ERROR ".$notice_message);update_option($db_ready_option_name,'no');set_transient($notice_transient_name,$notice_message,HOUR_IN_SECONDS*24);} if(!wp_next_scheduled('minichat_daily_license_check')){wp_schedule_event(time()+60,'daily','minichat_daily_license_check');if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: Scheduled license check.");} if(!wp_next_scheduled(MINICHAT_CONTEXT_UPDATE_HOOK)){wp_schedule_event(time()+120,'daily',MINICHAT_CONTEXT_UPDATE_HOOK);if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: Scheduled context cache update.");} if(MINICHAT_DEBUG_LOG)error_log("MC[Activate v".MINICHAT_VERSION."]: Activation hook finished.");
}
function minichat_plugin_deactivate() {
    if(MINICHAT_DEBUG_LOG) error_log("MC[Deactivate v".MINICHAT_VERSION."]: Run hook."); delete_option(MINICHAT_DB_READY_OPTION); delete_transient(MINICHAT_ADMIN_NOTICE_TRANSIENT); wp_clear_scheduled_hook('minichat_daily_license_check'); wp_clear_scheduled_hook(MINICHAT_CONTEXT_UPDATE_HOOK); if(MINICHAT_DEBUG_LOG) error_log("MC[Deactivate v".MINICHAT_VERSION."]: Cleaned options, transient, crons.");
}

// --- Admin Notices Hook & Callback ---
add_action('admin_notices', 'minichat_display_admin_notices');
// Definition remains here
function minichat_display_admin_notices() { $db_err=get_transient(MINICHAT_ADMIN_NOTICE_TRANSIENT); if($db_err){echo '<div class="notice notice-error is-dismissible"><p><strong>MC Config Error:</strong><br>'.nl2br(esc_html($db_err)).'</p></div>';} $lic_opts=get_option(MINICHAT_LICENSE_OPTIONS_NAME,[]); $lic_stat=$lic_opts['status']??'inactive'; $lic_val=$lic_opts['valid']??false; $current_screen=get_current_screen(); $is_mc_page=($current_screen && isset($current_screen->id) && strpos($current_screen->id,'minimal-chatbot')!==false); $trial_active=function_exists('minichat_is_trial_active')?minichat_is_trial_active():false; $trial_info=$trial_active&&function_exists('minichat_get_trial_info')?minichat_get_trial_info():null; $grace_active=function_exists('minichat_is_grace_period_active')?minichat_is_grace_period_active():false; $grace_info=$grace_active&&function_exists('minichat_get_grace_period_info')?minichat_get_grace_period_info():null; if(current_user_can('manage_options')&&!$is_mc_page){if($grace_active&&$grace_info){echo '<div class="notice notice-warning is-dismissible"><p><strong>MC:</strong> Operating in Grace Period. Expires in ' . esc_html($grace_info['time_remaining_human']) . '. <a href="'.esc_url(admin_url('admin.php?page=minimal-chatbot-license')).'">Details</a>.</p></div>';} elseif ($trial_active&&$trial_info){echo '<div class="notice notice-info is-dismissible"><p><strong>MC:</strong> Trial mode active! ' . esc_html($trial_info['days_remaining']) . ' days left. <a href="'.esc_url(admin_url('admin.php?page=minimal-chatbot-license')).'">Activate</a>.</p></div>';} elseif(!$lic_val&&!empty(get_option('minichat_api_key'))&&!$trial_active&&!$grace_active){echo '<div class="notice notice-error is-dismissible"><p><strong>MC:</strong> '.sprintf('License inactive/invalid (Status: %s). <a href="%s">Check license</a> or <a href="%s">start trial</a>.', esc_html(ucfirst($lic_stat)), esc_url(admin_url('admin.php?page=minimal-chatbot-license')), esc_url(admin_url('admin.php?page=minimal-chatbot-license'))).'</p></div>';} elseif(empty(get_option('minichat_api_key'))){echo '<div class="notice notice-warning is-dismissible"><p><strong>MC:</strong> '.sprintf('Please <a href="%s">enter API Key</a>.', esc_url(admin_url('admin.php?page=minimal-chatbot-settings'))).'</p></div>';}} }

// --- Cookie Management Hook & Callback ---
add_action('init', 'minichat_manage_user_cookie', 1);
// Definition remains here
function minichat_manage_user_cookie() { if(is_admin()||(wp_doing_ajax()&&(!isset($_REQUEST['action'])||strpos($_REQUEST['action'],'minichat_')!==0))){return;} if(session_status()==PHP_SESSION_NONE&&!headers_sent()){session_start();if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: Session started.");}elseif(headers_sent()&&session_status()==PHP_SESSION_NONE){if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: WARN Headers sent.");} $cn=MINICHAT_USER_COOKIE_NAME;$sk='minichat_user_id_val';$cv=null; if(isset($_COOKIE[$cn])&&!empty($_COOKIE[$cn])){$p='/[^a-fA-F0-9-]/';$sv=preg_replace($p,'',$_COOKIE[$cn]);if(!empty($sv)&&strlen($sv)>10){$cv=$sv;}else{if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: Invalid cookie {$cn}");}} if(!$cv){$uid=wp_generate_uuid4();if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: No valid cookie. New ID: {$uid}");$cd=intval(get_option('minichat_cookie_duration',30));if($cd<1)$cd=1;$exp=time()+($cd*86400);$path=COOKIEPATH?:'/';$dom=COOKIE_DOMAIN?:'';$sec=is_ssl();$http=true;$same='Lax'; if(!headers_sent()){$opts=['expires'=>$exp,'path'=>$path,'domain'=>$dom,'secure'=>$sec,'httponly'=>$http,'samesite'=>$same];if(PHP_VERSION_ID<70300)unset($opts['samesite']);$set=setcookie($cn,$uid,$opts);if($set){$_COOKIE[$cn]=$uid;if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: Set cookie.");}else{if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: ERR setcookie() false.");}}else{if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: ERR headers sent.");} if(session_status()==PHP_SESSION_ACTIVE){$_SESSION[$sk]=$uid;if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: Stored ID in SESSION.");}else{if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: WARN Session inactive.");}}else{if(session_status()==PHP_SESSION_ACTIVE&&(!isset($_SESSION[$sk])||$_SESSION[$sk]!==$cv)){$_SESSION[$sk]=$cv;if(MINICHAT_DEBUG_LOG)error_log("MC[Cookie]: Aligned SESSION.");}}}
// Definition of minichat_get_persistent_user_id moved to helper-functions.php

// --- Enqueue Scripts Hook & Callback ---
add_action('wp_enqueue_scripts', 'minichat_enqueue_frontend_assets');
// Definition remains here (includes is_front_page for JS)
function minichat_enqueue_frontend_assets() {
    $db_ok=(get_option(MINICHAT_DB_READY_OPTION)==='yes'); $api_ok=!empty(get_option('minichat_api_key')); $lic_ok=function_exists('minichat_is_license_valid')?minichat_is_license_valid():false;
    if(!$db_ok||!$api_ok||!$lic_ok){if(MINICHAT_DEBUG_LOG){$r=[];if(!$db_ok)$r[]="DB";if(!$api_ok)$r[]="API";if(!$lic_ok)$r[]="Lic/Trial";error_log("MC[Frontend]: Skip enqueue(".implode(',',$r).")");}return;}
    if(MINICHAT_DEBUG_LOG)error_log("MC[Frontend]: Enqueue Assets v".MINICHAT_VERSION);
    wp_enqueue_style('minichat-styles',MINICHAT_PLUGIN_URL.'minimal-chatbot.css',[],MINICHAT_VERSION); wp_enqueue_style('dashicons'); wp_enqueue_script('minichat-scripts',MINICHAT_PLUGIN_URL.'minimal-chatbot.js',['jquery'],MINICHAT_VERSION,true);
    $trial_active=function_exists('minichat_is_trial_active')?minichat_is_trial_active():false; $trial_info=$trial_active&&function_exists('minichat_get_trial_info')?minichat_get_trial_info():null; $grace_active=function_exists('minichat_is_grace_period_active')?minichat_is_grace_period_active():false;
    $settings_to_pass=['position'=>get_option('minichat_position','bottom-right'),'primary_color'=>get_option('minichat_primary_color','#555'),'text_color'=>get_option('minichat_text_color','#333'),'header_title'=>get_option('minichat_header_title','Robutech AI'),'enable_feedback'=>(bool)get_option('minichat_enable_feedback',true),'enable_stt'=>(bool)get_option('minichat_enable_stt',false),'enable_tts'=>(bool)get_option('minichat_enable_tts',false),'avatar_bot_url'=>get_option('minichat_bot_avatar_url',''),'avatar_user_url'=>'','enable_auto_open'=>(bool)get_option('minichat_enable_auto_open',false),'inactivity_delay'=>intval(get_option('minichat_inactivity_delay',30)),'auto_open_frequency'=>get_option('minichat_auto_open_frequency','once_per_session'),'auto_open_pages'=>get_option('minichat_auto_open_pages','all'),'initial_greeting'=>get_option('minichat_initial_greeting','Hallo! Frag mich etwas.'),'proactive_message'=>get_option('minichat_proactive_message','Hallo! Kann ich Ihnen helfen?'),'trial_mode'=>$trial_active,'trial_message_limit'=>MINICHAT_MESSAGES_LIMIT_TRIAL,'grace_period_active'=>$grace_active, 'is_front_page' => is_front_page() ]; // is_front_page added
    if($trial_active&&$trial_info){$settings_to_pass['trial_days_remaining']=$trial_info['days_remaining'];}
    wp_localize_script('minichat-scripts','minichat_data',['ajax_url'=>admin_url('admin-ajax.php'),'nonce'=>wp_create_nonce('minichat_nonce'),'license_nonce'=>wp_create_nonce('minichat_license_nonce'), 'feedback_nonce'=>wp_create_nonce('minichat_feedback_nonce'), 'clear_chat_nonce'=>wp_create_nonce('minichat_clear_chat_nonce'), 'context_nonce'=>wp_create_nonce('minichat_context_nonce'), 'settings'=>$settings_to_pass]); // context_nonce added
}

// --- Admin Menu Hook & Callback ---
add_action('admin_menu', 'minichat_add_admin_menu');
// Definition remains here
function minichat_add_admin_menu() { if(MINICHAT_DEBUG_LOG)error_log("MC[AdminMenu v".MINICHAT_VERSION."]: Add menus..."); $main_cb='minichat_settings_page_html'; $status_cb='minichat_status_page_html'; $context_cb='minichat_context_settings_page_html'; $license_cb='minichat_license_page_html'; $feedback_cb='minichat_feedback_page_html'; if(!function_exists($main_cb))$main_cb=null; if(!function_exists($status_cb))$status_cb=null; if(!function_exists($context_cb))$context_cb=null; if(!function_exists($license_cb))$license_cb=null; if(!function_exists($feedback_cb))$feedback_cb=null; add_menu_page(__('Settings','minimal-chatbot'),__('Mini Chatbot','minimal-chatbot'),'manage_options','minimal-chatbot-settings',$main_cb,'dashicons-format-chat',80); if($main_cb)add_submenu_page('minimal-chatbot-settings',__('Settings','minimal-chatbot'),__('Settings','minimal-chatbot'),'manage_options','minimal-chatbot-settings',$main_cb); if($status_cb)add_submenu_page('minimal-chatbot-settings',__('Status','minimal-chatbot'),__('Status & Users','minimal-chatbot'),'manage_options','minimal-chatbot-status',$status_cb); if($context_cb)add_submenu_page('minimal-chatbot-settings',__('Context','minimal-chatbot'),__('Context','minimal-chatbot'),'manage_options','minimal-chatbot-context',$context_cb); if($license_cb)add_submenu_page('minimal-chatbot-settings',__('License','minimal-chatbot'),__('License','minimal-chatbot'),'manage_options','minimal-chatbot-license',$license_cb); if($feedback_cb)add_submenu_page('minimal-chatbot-settings',__('Feedback','minimal-chatbot'),__('Feedback','minimal-chatbot'),'manage_options','minimal-chatbot-feedback',$feedback_cb); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminMenu v".MINICHAT_VERSION."]: Menus added."); }

// --- Register Settings Hook & Callback ---
add_action('admin_init', 'minichat_settings_init');
// Definition remains here (uses separate groups)
function minichat_settings_init() { if(MINICHAT_DEBUG_LOG) error_log("MC[AdminInit v".MINICHAT_VERSION."]: Running settings init..."); $csg='minichat_settings_group'; $ctxg='minichat_context_settings_group'; $mp='minimal-chatbot-settings'; $cp='minimal-chatbot-context'; try { register_setting($csg,'minichat_api_key',['type'=>'string','sanitize_callback'=>'sanitize_text_field','default'=>'']); register_setting($csg,'minichat_openai_model',['type'=>'string','sanitize_callback'=>'sanitize_text_field','default'=>'gpt-4o']); register_setting($csg,'minichat_system_prompt',['type'=>'string','sanitize_callback'=>'wp_kses_post','default'=>'You are a helpful assistant.']); register_setting($csg,'minichat_cookie_duration',['type'=>'integer','sanitize_callback'=>'absint','default'=>30]); register_setting($csg,'minichat_memory_depth',['type'=>'integer','sanitize_callback'=>'absint','default'=>10]); register_setting($csg,'minichat_primary_color',['type'=>'string','sanitize_callback'=>'sanitize_hex_color','default'=>'#555']); register_setting($csg,'minichat_text_color',['type'=>'string','sanitize_callback'=>'sanitize_hex_color','default'=>'#333']); register_setting($csg,'minichat_position',['type'=>'string','sanitize_callback'=>'sanitize_key','default'=>'bottom-right']); register_setting($csg,'minichat_header_title',['type'=>'string','sanitize_callback'=>'sanitize_text_field','default'=>'Robutech AI']); register_setting($csg,'minichat_bot_avatar_url',['type'=>'string','sanitize_callback'=>'esc_url_raw','default'=>'']); register_setting($csg,'minichat_enable_stt',['type'=>'boolean','sanitize_callback'=>'rest_sanitize_boolean','default'=>false]); register_setting($csg,'minichat_enable_tts',['type'=>'boolean','sanitize_callback'=>'rest_sanitize_boolean','default'=>false]); register_setting($csg,'minichat_enable_feedback',['type'=>'boolean','sanitize_callback'=>'rest_sanitize_boolean','default'=>true]); register_setting($csg,'minichat_enable_auto_open',['type'=>'boolean','sanitize_callback'=>'rest_sanitize_boolean','default'=>false]); register_setting($csg,'minichat_inactivity_delay',['type'=>'integer','sanitize_callback'=>'absint','default'=>30]); register_setting($csg,'minichat_auto_open_frequency',['type'=>'string','sanitize_callback'=>'sanitize_key','default'=>'once_per_session']); register_setting($csg,'minichat_auto_open_pages',['type'=>'string','sanitize_callback'=>'sanitize_key','default'=>'all']); register_setting($csg,'minichat_initial_greeting',['type'=>'string','sanitize_callback'=>'sanitize_text_field','default'=>'Hallo! Frag mich etwas.']); register_setting($csg,'minichat_proactive_message',['type'=>'string','sanitize_callback'=>'sanitize_text_field','default'=>'Hallo! Kann ich Ihnen helfen?']); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: Registered core settings: ".$csg); add_settings_section('minichat_api_section',__('API & Model','minimal-chatbot'),null,$mp); add_settings_field('minichat_api_key_field',__('API Key','minimal-chatbot'),'minichat_api_key_callback',$mp,'minichat_api_section'); add_settings_field('minichat_openai_model_field',__('Model','minimal-chatbot'),'minichat_openai_model_callback',$mp,'minichat_api_section'); add_settings_section('minichat_behavior_section',__('Behavior','minimal-chatbot'),null,$mp); add_settings_field('minichat_system_prompt_field',__('Prompt','minimal-chatbot'),'minichat_system_prompt_callback',$mp,'minichat_behavior_section'); add_settings_section('minichat_memory_section',__('Memory','minimal-chatbot'),null,$mp); add_settings_field('minichat_cookie_duration_field',__('Cookie','minimal-chatbot'),'minichat_cookie_duration_callback',$mp,'minichat_memory_section'); add_settings_field('minichat_memory_depth_field',__('Memory Depth','minimal-chatbot'),'minichat_memory_depth_callback',$mp,'minichat_memory_section'); add_settings_section('minichat_appearance_section',__('Appearance','minimal-chatbot'),null,$mp); add_settings_field('minichat_primary_color_field',__('Color','minimal-chatbot'),'minichat_primary_color_callback',$mp,'minichat_appearance_section'); add_settings_field('minichat_text_color_field',__('Text Color','minimal-chatbot'),'minichat_text_color_callback',$mp,'minichat_appearance_section'); add_settings_field('minichat_position_field',__('Position','minimal-chatbot'),'minichat_position_callback',$mp,'minichat_appearance_section'); add_settings_field('minichat_header_title_field',__('Header','minimal-chatbot'),'minichat_header_title_callback',$mp,'minichat_appearance_section'); add_settings_field('minichat_bot_avatar_url_field',__('Avatar','minimal-chatbot'),'minichat_bot_avatar_url_callback',$mp,'minichat_appearance_section'); add_settings_section('minichat_features_section',__('Features','minimal-chatbot'),null,$mp); add_settings_field('minichat_enable_stt_field',__('STT','minimal-chatbot'),'minichat_enable_stt_callback',$mp,'minichat_features_section'); add_settings_field('minichat_enable_tts_field',__('TTS','minimal-chatbot'),'minichat_enable_tts_callback',$mp,'minichat_features_section'); add_settings_field('minichat_enable_feedback_field',__('Feedback','minimal-chatbot'),'minichat_enable_feedback_callback',$mp,'minichat_features_section'); add_settings_section('minichat_proactive_section',__('Proactive','minimal-chatbot'),null,$mp); add_settings_field('minichat_enable_auto_open_field',__('Auto-Open','minimal-chatbot'),'minichat_enable_auto_open_callback',$mp,'minichat_proactive_section'); add_settings_field('minichat_inactivity_delay_field',__('Delay','minimal-chatbot'),'minichat_inactivity_delay_callback',$mp,'minichat_proactive_section'); add_settings_field('minichat_auto_open_frequency_field',__('Frequency','minimal-chatbot'),'minichat_auto_open_frequency_callback',$mp,'minichat_proactive_section'); add_settings_field('minichat_auto_open_pages_field',__('Pages','minimal-chatbot'),'minichat_auto_open_pages_callback',$mp,'minichat_proactive_section'); add_settings_field('minichat_initial_greeting_field',__('Greeting','minimal-chatbot'),'minichat_initial_greeting_callback',$mp,'minichat_proactive_section'); add_settings_field('minichat_proactive_message_field',__('Proactive Msg','minimal-chatbot'),'minichat_proactive_message_callback',$mp,'minichat_proactive_section'); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: Added core sections/fields."); register_setting($ctxg,'minichat_context_pages',['type'=>'array','sanitize_callback'=>'minichat_sanitize_context_pages','default'=>[]]); register_setting($ctxg,'minichat_context_cache_limit',['type'=>'integer','sanitize_callback'=>'absint','default'=>MINICHAT_DEFAULT_CACHE_LIMIT]); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: Registered context settings: ".$ctxg); add_settings_section('minichat_context_selection_section',__('Context Pages','minimal-chatbot'),'minichat_context_selection_section_callback',$cp); add_settings_field('minichat_context_pages_field',__('Select Pages','minimal-chatbot'),'minichat_context_pages_callback',$cp,'minichat_context_selection_section'); add_settings_field('minichat_context_cache_limit_field',__('Cache Limit','minimal-chatbot'),'minichat_context_cache_limit_callback',$cp,'minichat_context_selection_section'); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: Added context section/fields to page: ".$cp); register_setting('minichat_license_group',MINICHAT_LICENSE_OPTIONS_NAME,['type'=>'array','sanitize_callback'=>'minichat_sanitize_license_options','default'=>['key'=>'','status'=>'inactive','valid'=>false,'message'=>'','data'=>null,'last_checked'=>'']]); if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: Registered license group."); } catch(Exception $e){if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: EXCEPTION: ".$e->getMessage());} catch(Error $e){if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit]: PHP ERROR: ".$e->getMessage());} if(MINICHAT_DEBUG_LOG)error_log("MC[AdminInit v".MINICHAT_VERSION."]: Finished init."); }

// --- Settings Callbacks (Definitions remain here) ---
// Includes fixes for Model callback and Cache Limit default value
function minichat_api_key_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render API Key field"); $k=get_option('minichat_api_key',''); echo '<input type="password" name="minichat_api_key" value="'.esc_attr($k).'" class="regular-text" autocomplete="off"/>'; echo '<p class="description">'.__('Enter your OpenAI API key.','minimal-chatbot').'</p>'; if(empty($k)) echo '<p style="color:red;font-weight:bold;">'.__('Not set!','minimal-chatbot').'</p>'; else echo '<p style="color:green;">'.__('Set','minimal-chatbot').' (...'.esc_html(substr($k,-4)).').</p>'; }
function minichat_openai_model_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Model field"); $api_key=get_option('minichat_api_key'); $current_model=get_option('minichat_openai_model','gpt-4o'); if(empty($api_key)){ echo '<p><i>'.__('Enter API Key above to fetch available models. Default:','minimal-chatbot').' <strong>'.esc_html($current_model).'</strong></i></p>'; echo '<input type="text" name="minichat_openai_model" value="'.esc_attr($current_model).'" class="regular-text code" list="common-models-fallback" placeholder="e.g., gpt-4o"/>'; echo '<datalist id="common-models-fallback"><option value="gpt-4o"><option value="gpt-4-turbo"><option value="gpt-3.5-turbo"></datalist>'; return; } $models = minichat_get_openai_models($api_key); if (isset($models['error'])) { echo '<p style="color:red;">'.__('Error fetching models:','minimal-chatbot').' '.esc_html($models['error']).'</p>'; echo __('Enter model manually or fix API key issue:','minimal-chatbot').' <input type="text" name="minichat_openai_model" value="'.esc_attr($current_model).'" class="regular-text code" list="common-models-error"/>'; echo '<datalist id="common-models-error"><option value="gpt-4o"><option value="gpt-4-turbo"><option value="gpt-3.5-turbo"></datalist>'; } elseif (is_array($models) && !empty($models)) { echo '<select name="minichat_openai_model" class="regular-text">'; if (!isset($models[$current_model]) && !empty($current_model)) { if (MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Current model '{$current_model}' not in fetched list. Adding it."); echo '<option value="'.esc_attr($current_model).'" selected="selected">'.esc_html($current_model).' ('.__('Saved','minimal-chatbot').')</option>'; } foreach ($models as $model_id => $model_display) { echo '<option value="'.esc_attr($model_id).'" '.selected($current_model, $model_id, false).'>'.esc_html($model_display).'</option>'; } echo '</select>'; } else { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Model field - Unexpected state for \$models variable after fetch attempt. Value: " . print_r($models, true)); echo '<p style="color:orange;">'.__('Could not retrieve or process model list. Please check API key and connection. Using saved/default value.','minimal-chatbot').'</p>'; echo '<input type="text" name="minichat_openai_model" value="'.esc_attr($current_model).'" class="regular-text code" list="common-models-fallback"/>'; echo '<datalist id="common-models-fallback"><option value="gpt-4o"><option value="gpt-4-turbo"><option value="gpt-3.5-turbo"></datalist>'; } echo '<p class="description">'.__('Select the OpenAI model to use. Models are fetched via the API.','minimal-chatbot').'</p>'; }
function minichat_system_prompt_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Prompt field START"); $p=get_option('minichat_system_prompt','You are a helpful assistant.'); echo '<textarea name="minichat_system_prompt" rows="6" class="large-text">'.esc_textarea($p).'</textarea>'; echo '<p class="description">'.__('Define the persona and instructions for the bot. Basic HTML allowed. The website name and description will be automatically prepended.','minimal-chatbot').'</p>'; if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Prompt field END");}
function minichat_cookie_duration_callback() { $d=get_option('minichat_cookie_duration',30); echo '<input type="number" name="minichat_cookie_duration" value="'.esc_attr($d).'" class="small-text" min="1" max="3650"/> '.__('days','minimal-chatbot'); echo '<p class="description">'.__('How long the user\'s ID is remembered via cookie (Default: 30).','minimal-chatbot').'</p>'; }
function minichat_memory_depth_callback() { $d=get_option('minichat_memory_depth',10); echo '<input type="number" name="minichat_memory_depth" value="'.esc_attr($d).'" class="small-text" min="0" max="50"/> '.__('pairs','minimal-chatbot'); echo '<p class="description">'.__('How many past user/bot message pairs to include as context (0 = no history, Default: 10).','minimal-chatbot').'</p>'; }
function minichat_primary_color_callback() { $c=get_option('minichat_primary_color','#555'); echo '<input type="color" name="minichat_primary_color" value="'.esc_attr($c).'"/>'; echo '<p class="description">'.__('Main color for the widget header and user messages (Default: #555).','minimal-chatbot').'</p>'; }
function minichat_text_color_callback() { $c=get_option('minichat_text_color','#333'); echo '<input type="color" name="minichat_text_color" value="'.esc_attr($c).'"/>'; echo '<p class="description">'.__('Main text color within the widget, used for bot messages (Default: #333).','minimal-chatbot').'</p>'; }
function minichat_position_callback() { $p=get_option('minichat_position','bottom-right'); $opts=['bottom-right'=>'Bottom Right','bottom-left'=>'Bottom Left','top-right'=>'Top Right','top-left'=>'Top Left']; echo '<select name="minichat_position">'; foreach($opts as $v=>$l){echo '<option value="'.esc_attr($v).'" '.selected($p,$v,false).'>'.esc_html__($l,'minimal-chatbot').'</option>';} echo '</select>'; echo '<p class="description">'.__('Position of the chat widget on the screen (Default: Bottom Right).','minimal-chatbot').'</p>'; }
function minichat_header_title_callback() { $t=get_option('minichat_header_title','Robutech AI'); echo '<input type="text" name="minichat_header_title" value="'.esc_attr($t).'" class="regular-text"/>'; echo '<p class="description">'.__('Text displayed in the widget header (Default: Robutech AI).','minimal-chatbot').'</p>'; }
function minichat_bot_avatar_url_callback() { $u=get_option('minichat_bot_avatar_url',''); echo '<input type="url" name="minichat_bot_avatar_url" value="'.esc_attr($u).'" class="regular-text code" placeholder="https://..."/>'; echo '<p class="description">'.__('Optional URL for the bot\'s avatar image.','minimal-chatbot').'</p>'; if(!empty($u)) echo '<img src="'.esc_url($u).'" alt="Preview" style="max-width:40px;height:40px;border-radius:50%;vertical-align:middle;margin-left:10px;border:1px solid #ccc;"/>'; }
function minichat_enable_stt_callback() { $c=get_option('minichat_enable_stt',false); echo '<input type="checkbox" name="minichat_enable_stt" value="1" '.checked(1,$c,false).'/>'; echo '<label> '.__('Allow Speech-to-Text input using the browser\'s API.','minimal-chatbot').'</label>'; echo '<p class="description">'.__('Requires microphone permission in the browser. Quality may vary.','minimal-chatbot').'</p>';}
function minichat_enable_tts_callback() { $c=get_option('minichat_enable_tts',false); echo '<input type="checkbox" name="minichat_enable_tts" value="1" '.checked(1,$c,false).'/>'; echo '<label> '.__('Allow Text-to-Speech output using the browser\'s API.','minimal-chatbot').'</label>'; echo '<p class="description">'.__('Uses the browser\'s built-in voices. Quality may vary.','minimal-chatbot').'</p>';}
function minichat_enable_feedback_callback() { $c=get_option('minichat_enable_feedback',true); echo '<input type="checkbox" name="minichat_enable_feedback" value="1" '.checked(1,$c,false).'/>'; echo '<label> '.__('Allow users to provide feedback (thumbs up/down) on bot responses.','minimal-chatbot').'</label>';}
function minichat_enable_auto_open_callback() { $c=get_option('minichat_enable_auto_open',false); echo '<input type="checkbox" name="minichat_enable_auto_open" value="1" '.checked(1,$c,false).'/>'; echo '<label> '.__('Automatically maximize the chat widget after a period of inactivity.','minimal-chatbot').'</label>';}
function minichat_inactivity_delay_callback() { $d=get_option('minichat_inactivity_delay',30); echo '<input type="number" name="minichat_inactivity_delay" value="'.esc_attr($d).'" class="small-text" min="5" max="600"/> '.__('seconds','minimal-chatbot'); echo '<p class="description">'.__('Wait time before automatically opening the widget (Default: 30).','minimal-chatbot').'</p>';}
function minichat_auto_open_frequency_callback() { $f=get_option('minichat_auto_open_frequency','once_per_session'); $opts=['once_per_session'=>'Once per Session','always'=>'Always after inactivity']; echo '<select name="minichat_auto_open_frequency">'; foreach($opts as $v=>$l){echo '<option value="'.esc_attr($v).'" '.selected($f,$v,false).'>'.esc_html__($l,'minimal-chatbot').'</option>';} echo '</select>'; echo '<p class="description">'.__('How often the widget should auto-open after inactivity.','minimal-chatbot').'</p>';}
function minichat_auto_open_pages_callback() { $p=get_option('minichat_auto_open_pages','all'); $opts=['all'=>'All Pages','homepage'=>'Homepage Only']; echo '<select name="minichat_auto_open_pages">'; foreach($opts as $v=>$l){echo '<option value="'.esc_attr($v).'" '.selected($p,$v,false).'>'.esc_html__($l,'minimal-chatbot').'</option>';} echo '</select>'; echo '<p class="description">'.__('On which pages the widget should auto-open.','minimal-chatbot').'</p>';}
function minichat_initial_greeting_callback() { $t=get_option('minichat_initial_greeting','Hallo! Frag mich etwas.'); echo '<input type="text" name="minichat_initial_greeting" value="'.esc_attr($t).'" class="regular-text"/>'; echo '<p class="description">'.__('The first message displayed by the bot in an empty chat window.','minimal-chatbot').'</p>';}
function minichat_proactive_message_callback() { $t=get_option('minichat_proactive_message','Hallo! Kann ich Ihnen helfen?'); echo '<input type="text" name="minichat_proactive_message" value="'.esc_attr($t).'" class="regular-text"/>'; echo '<p class="description">'.__('The message displayed by the bot when it auto-opens due to inactivity.','minimal-chatbot').'</p>';}
function minichat_context_selection_section_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Context Section Desc"); echo '<p>' . __('Select specific pages whose content should be used as additional context for the chatbot. The content will be periodically cached.', 'minimal-chatbot') . '</p>'; echo '<p>' . __('The chatbot will first perform a simple keyword search in the cached content. If relevant content is found, it will be sent to the AI along with your question.', 'minimal-chatbot') . '</p>'; }
function minichat_context_pages_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Context Pages field START"); $selected_pages = get_option('minichat_context_pages', []); if (!is_array($selected_pages)) { $selected_pages = []; } $all_pages = get_pages(['post_status' => 'publish', 'sort_column' => 'post_title', 'sort_order' => 'ASC']); if (empty($all_pages)) { echo '<p>' . __('No published pages found to select.', 'minimal-chatbot') . '</p>'; if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Context Pages field END - No pages found."); return; } echo '<fieldset style="border: 1px solid #ccd0d4; padding: 10px 15px; max-height: 250px; overflow-y: auto; background-color: #fff;">'; echo '<legend class="screen-reader-text"><span>' . __('Select Pages for Context', 'minimal-chatbot') . '</span></legend>'; foreach ($all_pages as $page) { $page_id = $page->ID; if(empty($page_id)) continue; $checked = in_array($page_id, $selected_pages) ? 'checked="checked"' : ''; echo '<label style="display: block; margin-bottom: 8px; font-weight: normal;">'; echo '<input type="checkbox" name="minichat_context_pages[]" value="' . esc_attr($page_id) . '" ' . $checked . ' style="margin-right: 5px;" /> '; echo esc_html($page->post_title); echo '</label>'; } echo '</fieldset>'; echo '<p class="description">' . __('Check the pages the bot should use for context (e.g., About Us, FAQ, Services). Keep the selection limited for optimal performance and relevance.', 'minimal-chatbot') . '</p>'; if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Context Pages field END - Rendered " . count($all_pages) . " pages."); }
function minichat_context_cache_limit_callback() { if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Cache Limit field START"); $limit_value = get_option('minichat_context_cache_limit', MINICHAT_DEFAULT_CACHE_LIMIT); if ( empty($limit_value) ) { $limit_value = MINICHAT_DEFAULT_CACHE_LIMIT; if (MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Cache Limit was empty/zero in option, forcing default: " . $limit_value); } $limit_value = absint($limit_value); if ($limit_value < 500) { $limit_value = MINICHAT_DEFAULT_CACHE_LIMIT; } echo '<input type="number" name="minichat_context_cache_limit" value="' . esc_attr($limit_value) . '" class="small-text" min="500" max="50000" step="100"/> ' . __('characters', 'minimal-chatbot'); echo '<p class="description">' . sprintf(__('Maximum number of characters of content to cache per selected page (Default: %d). Longer content will be truncated.', 'minimal-chatbot'), MINICHAT_DEFAULT_CACHE_LIMIT) . '</p>'; if(MINICHAT_DEBUG_LOG) error_log("MC[Callback]: Render Cache Limit field END - Value: " . $limit_value); }
// Context Sanitizer
function minichat_sanitize_context_pages($input) { if (!is_array($input)) { return []; } return array_map('absint', $input); }

// --- Settings Page Rendering Functions ---
// Main Page
function minichat_settings_page_html() { if(!current_user_can('manage_options')){wp_die();} if(MINICHAT_DEBUG_LOG)error_log("MC[AdminPage]: Render MAIN settings..."); ?> <div class="wrap"> <h1><?php _e('Minimal Chatbot Settings','minimal-chatbot'); ?></h1> <?php settings_errors('minichat_settings_group'); ?> <form action="options.php" method="post"> <?php settings_fields('minichat_settings_group'); do_settings_sections('minimal-chatbot-settings'); submit_button(__('Save Settings','minimal-chatbot')); ?> </form> </div> <?php if(MINICHAT_DEBUG_LOG)error_log("MC[AdminPage]: Finish MAIN settings."); }
// Context Page
function minichat_context_settings_page_html() { if(!current_user_can('manage_options')){wp_die();} if(MINICHAT_DEBUG_LOG)error_log("MC[AdminPage]: Render CONTEXT settings..."); ?> <div class="wrap"> <h1><?php _e('Context Awareness Settings','minimal-chatbot'); ?></h1> <?php settings_errors('minichat_context_settings_group'); ?> <form action="options.php" method="post"> <?php settings_fields('minichat_context_settings_group'); do_settings_sections('minimal-chatbot-context'); submit_button(__('Save Context Settings','minimal-chatbot')); ?> </form> <hr> <h2><?php _e('Context Cache Status','minimal-chatbot'); ?></h2> <?php $cached_data=get_transient(MINICHAT_CONTEXT_CACHE_TRANSIENT); $next_run=wp_next_scheduled(MINICHAT_CONTEXT_UPDATE_HOOK); if($cached_data!==false&&is_array($cached_data)){echo '<p style="color:green;">'.__('Context cache is currently active.','minimal-chatbot').'</p>';if(count($cached_data)>0){echo '<p>'.sprintf(_n('%d page cached.','%d pages cached.',count($cached_data),'minimal-chatbot'),count($cached_data)).'</p>';echo '<ul style="list-style:disc;margin-left:20px;">';foreach($cached_data as $pid=>$c){$pt=get_the_title($pid);if($pt){echo '<li>'.esc_html($pt).' ('.sprintf(__('approx. %d chars','minimal-chatbot'),mb_strlen($c)).')</li>';}else{echo '<li>'.sprintf(__('Page ID %d (Title not found)','minimal-chatbot'),$pid).' ('.sprintf(__('approx. %d chars','minimal-chatbot'),mb_strlen($c)).')</li>';}}echo '</ul>';}else{echo '<p>'.__('No pages are currently selected for caching.','minimal-chatbot').'</p>';}}else{echo '<p style="color:orange;">'.__('Context cache is not yet generated or has expired.','minimal-chatbot').'</p>';} if($next_run){echo '<p>'.sprintf(__('Next automatic cache update: %s (UTC)','minimal-chatbot'),esc_html(get_date_from_gmt(date('Y-m-d H:i:s',$next_run),'Y-m-d H:i:s'))).'</p>';}else{echo '<p style="color:red;">'.__('Cache update schedule not found!','minimal-chatbot').'</p>';} ?> <form method="post" action="<?php echo esc_url(admin_url('admin-post.php')); ?>" style="margin-top:10px;"><input type="hidden" name="action" value="minichat_force_cache_update"><?php wp_nonce_field('minichat_force_cache_update_nonce'); ?><?php submit_button(__('Update Cache Now','minimal-chatbot'),'secondary','update_cache_submit',false); ?><p class="description"><?php _e('Manually trigger the cache update process. Useful after changing settings or page content.','minimal-chatbot'); ?></p></form> </div> <?php if(MINICHAT_DEBUG_LOG)error_log("MC[AdminPage]: Finish CONTEXT settings."); }

// --- Manual Cache Update Handler & Notice ---
add_action('admin_post_minichat_force_cache_update', 'minichat_handle_force_cache_update');
function minichat_handle_force_cache_update() { if(!current_user_can('manage_options')||!check_admin_referer('minichat_force_cache_update_nonce')){wp_die('Denied.');} if(MINICHAT_DEBUG_LOG)error_log("MC[AdminPost]: Force cache update triggered."); minichat_run_context_cache_update(); wp_redirect(add_query_arg('cache_updated','true',admin_url('admin.php?page=minimal-chatbot-context'))); exit; }
add_action('admin_notices', 'minichat_display_cache_update_notice');
function minichat_display_cache_update_notice() { $scr=get_current_screen(); if($scr && $scr->id==='mini-chatbot_page_minimal-chatbot-context' && isset($_GET['cache_updated'])&&$_GET['cache_updated']==='true'){if(MINICHAT_DEBUG_LOG)error_log("MC[AdminNotice]: Display cache update notice."); echo '<div class="notice notice-success is-dismissible"><p>'.__('Context cache updated!','minimal-chatbot').'</p></div>';}}

// --- License Options Sanitizer (Stub) ---
if (!function_exists('minichat_sanitize_license_options')) { function minichat_sanitize_license_options($i){$o=[];$o['key']=isset($i['key'])?sanitize_text_field($i['key']):'';$o['status']=isset($i['status'])?sanitize_key($i['status']):'inactive';$o['valid']=isset($i['valid'])?(bool)$i['valid']:false;$o['message']=isset($i['message'])?sanitize_text_field($i['message']):'';$o['data']=isset($i['data'])?$i['data']:null;$o['last_checked']=isset($i['last_checked'])?sanitize_text_field($i['last_checked']):'';return $o;} }

// --- Cron Hooks ---
add_action(MINICHAT_CONTEXT_UPDATE_HOOK, 'minichat_run_context_cache_update'); // Definition is in helper-functions.php
add_action('minichat_daily_license_check', 'minichat_perform_daily_license_check');

// --- License Cron Action Definition ---
if (!function_exists('minichat_perform_daily_license_check')) { function minichat_perform_daily_license_check() { $debug_log=defined('MINICHAT_DEBUG_LOG')&&MINICHAT_DEBUG_LOG; if($debug_log)error_log("MC[Cron]: Run daily license check..."); $options=get_option(MINICHAT_LICENSE_OPTIONS_NAME,[]); $key=$options['key']??''; if(!empty($key)&&function_exists('minichat_verify_license_remote')){$result=minichat_verify_license_remote($key); if(isset($result['error'])){if($debug_log)error_log("MC[Cron]: ERR check: ".$result['error']);}else{if($debug_log)error_log("MC[Cron]: OK check. Status: ".($result['status']??'unknown').", Valid: ".(isset($result['valid'])&&$result['valid']?'Yes':'No'));}}else{if($debug_log)error_log("MC[Cron]: Skip check, no key or verification function missing.");}} }

// --- Frontend Widget Hook & Callback ---
add_action('wp_footer', 'minichat_render_frontend_widget');
// Definition remains here
function minichat_render_frontend_widget() { $db_ok=(get_option(MINICHAT_DB_READY_OPTION)==='yes'); $api_ok=!empty(get_option('minichat_api_key')); $lic_ok=function_exists('minichat_is_license_valid')?minichat_is_license_valid():false; if(!$db_ok||!$api_ok||!$lic_ok){ echo ""; return; } $pos=get_option('minichat_position','bottom-right'); $pcol=get_option('minichat_primary_color','#555'); $tcol=get_option('minichat_text_color','#333'); $htitle=get_option('minichat_header_title','Robutech AI'); $enable_stt=(bool)get_option('minichat_enable_stt',false); $bot_avatar_url=get_option('minichat_bot_avatar_url',''); $initial_greeting=get_option('minichat_initial_greeting','Hallo! Frag mich etwas.'); $avatar_style=''; if(!empty($bot_avatar_url)){$avatar_style='style="background-image:url(\''.esc_url($bot_avatar_url).'\'); background-size: cover;"';} $trial_active = function_exists('minichat_is_trial_active')?minichat_is_trial_active():false; $trial_info = $trial_active && function_exists('minichat_get_trial_info')?minichat_get_trial_info():null; $trial_class = $trial_active?'minichat-trial-mode':''; if(MINICHAT_DEBUG_LOG)error_log("MC[Widget]:Render HTML v".MINICHAT_VERSION.". Trial: ".($trial_active?'Yes':'No')); ?> <div id="minichat-container" class="<?php echo esc_attr($pos);?> <?php echo esc_attr($trial_class); ?>" style="--minichat-primary-color:<?php echo esc_attr($pcol);?>;--minichat-text-color:<?php echo esc_attr($tcol);?>;"> <div id="minichat-widget" class="minimized"> <div id="minichat-header"><span class="minichat-header-title"><?php echo esc_html($htitle);?><?php if($trial_active): ?> <small style="font-size:0.8em;opacity:0.8;">(Trial)</small><?php endif; ?></span><span class="minichat-header-controls"><span class="minichat-settings-btn dashicons dashicons-admin-generic" title="Options"></span><span class="minichat-minimize-btn dashicons dashicons-minus" title="Minimize"></span></span></div> <div id="minichat-body" style="display:none;"> <?php if($trial_active && $trial_info): ?> <div class="minichat-trial-banner" style="background-color: rgba(255,193,7,0.1); padding: 5px 10px; font-size: 12px; border-bottom: 1px solid #ffc107; text-align: center;"> Trial Mode: <?php echo esc_html($trial_info['days_remaining']); ?> days remaining | <a href="<?php echo esc_url(admin_url('admin.php?page=minimal-chatbot-license')); ?>" target="_blank" style="color:inherit;text-decoration:underline;">Activate License</a> | <?php echo sprintf(__('Limit: %d msgs/user','minimal-chatbot'), MINICHAT_MESSAGES_LIMIT_TRIAL); ?> </div> <?php endif; ?> <div id="minichat-messages"><div class="message-wrapper bot-message-wrapper initial-greeting"><span class="minichat-avatar bot" <?php echo $avatar_style; ?>></span><div class="message bot-message"><div class="message-content"><?php echo nl2br(esc_html($initial_greeting)); ?></div></div></div></div> <div id="minichat-input-area"><input type="text" id="minichat-input" placeholder="Schreibe eine Nachricht..." autocomplete="off"><div id="minichat-input-controls"><?php if($enable_stt):?><button id="minichat-voice-button" class="minichat-icon-button" title="Spracheingabe"><span class="dashicons dashicons-microphone"></span></button><?php endif;?><button id="minichat-send-button" class="minichat-icon-button" title="Senden"><span class="dashicons dashicons-arrow-right-alt2"></span></button></div></div> </div> <div id="minichat-options-popup" style="display: none;"><button class="minichat-option-button" id="minichat-clear-chat-btn"><span class="dashicons dashicons-trash"></span> Chat löschen</button><?php if($trial_active): ?><a href="<?php echo esc_url(admin_url('admin.php?page=minimal-chatbot-license')); ?>" target="_blank" class="minichat-option-button"><span class="dashicons dashicons-admin-network"></span> Aktiviere Lizenz</a><?php endif; ?></div> </div> </div> <style> /* Inline styles for trial banner */ .minichat-trial-banner a { color: inherit !important; text-decoration: underline !important; } </style> <?php }

// --- AJAX Action Hooks (Callbacks are in ajax-handlers.php) ---
add_action('wp_ajax_minichat_send_message', 'minichat_handle_ajax_message');
add_action('wp_ajax_nopriv_minichat_send_message', 'minichat_handle_ajax_message');
add_action('wp_ajax_minichat_send_feedback', 'minichat_handle_ajax_feedback');
add_action('wp_ajax_nopriv_minichat_send_feedback', 'minichat_handle_ajax_feedback');
add_action('wp_ajax_minichat_clear_chat', 'minichat_handle_ajax_clear_chat');
add_action('wp_ajax_nopriv_minichat_clear_chat', 'minichat_handle_ajax_clear_chat');
add_action('wp_ajax_minichat_activate_trial', 'minichat_handle_ajax_activate_trial');
add_action('wp_ajax_minichat_activate_license', 'minichat_handle_ajax_activate_license');
add_action('wp_ajax_minichat_verify_license', 'minichat_handle_ajax_verify_license');
add_action('wp_ajax_minichat_get_message_context', 'minichat_handle_ajax_get_context');

// --- Helper Function Definitions ARE NOW IN includes/helper-functions.php ---
// --- AJAX Handler Function Definitions ARE NOW IN includes/ajax-handlers.php ---

?>