<?php
// VOR dem Start: Versuche zu loggen
error_log("WC Addon Log: -- Top of woocommerce-minichat-addon.php reached --");

/**
 * Plugin Name:       WooCommerce Integration for Minimal Chatbot
 * Plugin URI:        [Deine Plugin-URI, falls vorhanden]
 * Description:       Extends Minimal Chatbot to search and display WooCommerce products. Creates a dedicated settings page under WooCommerce menu. Requires Minimal Chatbot and WooCommerce.
 * Version:           1.1.0
 * Author:            [Robutech]
 * Author URI:        [Robutech.ch]
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       wc-minichat-addon
 * Domain Path:       /languages
 * Requires Plugins:  minimal-chatbot/minimal-chatbot.php, woocommerce/woocommerce.php // Hinweis: Dieser Header dient nur der Info, die Prüfung erfolgt im Code
 * Requires PHP:      7.4
 * Requires at least: 5.8
 */

// Prevent direct access
if (!defined('ABSPATH')) {
    error_log("WC Addon Log: ERROR - ABSPATH not defined, exiting.");
    exit;
}
error_log("WC Addon Log: ABSPATH check passed.");

// --- Constants ---
error_log("WC Addon Log: Defining constants...");
if (!defined('WC_MINICHAT_ADDON_VERSION')) {
    define('WC_MINICHAT_ADDON_VERSION', '1.1.0');
    error_log("WC Addon Log: Constant WC_MINICHAT_ADDON_VERSION defined.");
}
if (!defined('WC_MINICHAT_ADDON_PATH')) {
    define('WC_MINICHAT_ADDON_PATH', plugin_dir_path(__FILE__));
    error_log("WC Addon Log: Constant WC_MINICHAT_ADDON_PATH defined: " . WC_MINICHAT_ADDON_PATH);
}
if (!defined('WC_MINICHAT_ADDON_URL')) {
    define('WC_MINICHAT_ADDON_URL', plugin_dir_url(__FILE__));
    error_log("WC Addon Log: Constant WC_MINICHAT_ADDON_URL defined: " . WC_MINICHAT_ADDON_URL);
}

// !! WICHTIG: Überprüfe diesen Pfad! Er muss exakt zum Ordner/Dateinamen deines Haupt-Chatbot-Plugins passen !!
if (!defined('MINICHAT_CORE_PLUGIN_SLUG')) {
    // Standard-Annahme (wie von dir bestätigt):
    define('MINICHAT_CORE_PLUGIN_SLUG', 'minimal-chatbot/minimal-chatbot.php');
    error_log("WC Addon Log: Constant MINICHAT_CORE_PLUGIN_SLUG defined: " . MINICHAT_CORE_PLUGIN_SLUG);
}

// Slug for WooCommerce (Standard)
if (!defined('WOOCOMMERCE_PLUGIN_SLUG')) {
    define('WOOCOMMERCE_PLUGIN_SLUG', 'woocommerce/woocommerce.php');
    error_log("WC Addon Log: Constant WOOCOMMERCE_PLUGIN_SLUG defined: " . WOOCOMMERCE_PLUGIN_SLUG);
}

// Slug for the new admin page
if (!defined('WC_MINICHAT_ADDON_PAGE_SLUG')) {
    define('WC_MINICHAT_ADDON_PAGE_SLUG', 'wc-minichat-settings');
    error_log("WC Addon Log: Constant WC_MINICHAT_ADDON_PAGE_SLUG defined: " . WC_MINICHAT_ADDON_PAGE_SLUG);
}
error_log("WC Addon Log: Constants definition finished.");

/**
 * Class WC_Minichat_Addon
 *
 * Main class for the Add-on plugin. Handles dependency checks, loading files,
 * enqueueing assets, and adding the admin menu/page.
 */
error_log("WC Addon Log: Defining class WC_Minichat_Addon...");
class WC_Minichat_Addon {

    private static $core_plugin_active = false;
    private static $woocommerce_active = false;
    private static $dependencies_met = false;
    private static $admin_notices = [];

    public static function init() {
        error_log("WC Addon Log: WC_Minichat_Addon::init() called.");
        // Run dependency check early
        add_action('plugins_loaded', [__CLASS__, 'check_dependencies'], 1);
        error_log("WC Addon Log: init() - Added check_dependencies hook.");

        // Load translations
        add_action('plugins_loaded', [__CLASS__, 'load_textdomain']);
        error_log("WC Addon Log: init() - Added load_textdomain hook.");

        // Load files if core plugin is active
        add_action('plugins_loaded', [__CLASS__, 'load_files'], 5);
        error_log("WC Addon Log: init() - Added load_files hook.");

        // Add admin menu item (conditionally placed)
        add_action('admin_menu', [__CLASS__, 'add_admin_menu']);
        error_log("WC Addon Log: init() - Added add_admin_menu hook.");

        // Enqueue frontend assets (only if all dependencies met)
        add_action('wp_enqueue_scripts', [__CLASS__, 'enqueue_frontend_assets']);
        error_log("WC Addon Log: init() - Added enqueue_frontend_assets hook.");

        // Display admin notices for missing dependencies
        add_action('admin_notices', [__CLASS__, 'display_admin_notices']);
        error_log("WC Addon Log: init() - Added display_admin_notices hook.");
        error_log("WC Addon Log: WC_Minichat_Addon::init() finished.");
    }

    public static function check_dependencies() {
        error_log("WC Addon Log: check_dependencies() called.");
        // Ensure the is_plugin_active function is available.
        if (!function_exists('is_plugin_active')) {
            error_log("WC Addon Log: check_dependencies() - is_plugin_active not found, including /wp-admin/includes/plugin.php");
            include_once(ABSPATH . 'wp-admin/includes/plugin.php');
            if (!function_exists('is_plugin_active')) {
                 error_log("WC Addon Log: check_dependencies() - FAILED to include or find is_plugin_active. Cannot check dependencies.");
                 // Set dependencies as not met if function is unavailable
                 self::$dependencies_met = false;
                 self::$core_plugin_active = false;
                 self::$woocommerce_active = false;
                 self::$admin_notices[] = __('Critical Error: Could not check plugin dependencies.', 'wc-minichat-addon');
                 return; // Exit the function early
            }
        }
        error_log("WC Addon Log: check_dependencies() - is_plugin_active function exists.");

        // Check using the defined constants
        error_log("WC Addon Log: check_dependencies() - Checking core plugin: " . MINICHAT_CORE_PLUGIN_SLUG);
        self::$core_plugin_active = is_plugin_active(MINICHAT_CORE_PLUGIN_SLUG);
        error_log("WC Addon Log: check_dependencies() - Core active: " . (self::$core_plugin_active ? 'Yes' : 'No'));

        error_log("WC Addon Log: check_dependencies() - Checking WC plugin: " . WOOCOMMERCE_PLUGIN_SLUG);
        self::$woocommerce_active = is_plugin_active(WOOCOMMERCE_PLUGIN_SLUG);
        error_log("WC Addon Log: check_dependencies() - WC active: " . (self::$woocommerce_active ? 'Yes' : 'No'));

        // Check if core plugin is missing
        if (!self::$core_plugin_active) {
             error_log("WC Addon Log: check_dependencies() - Core plugin INACTIVE. Adding notice.");
            self::$admin_notices[] = sprintf(
                __('WooCommerce Integration requires the main "%s" plugin (Path: %s) to be active. Please activate it.', 'wc-minichat-addon'),
                'Minimal Chatbot',
                esc_html(MINICHAT_CORE_PLUGIN_SLUG)
            );
            self::$dependencies_met = false;
            error_log("WC Addon Log: check_dependencies() finished (Core inactive).");
            return;
        }

        // Check if WooCommerce is missing (only relevant if core is active)
        if (!self::$woocommerce_active) {
            error_log("WC Addon Log: check_dependencies() - WooCommerce plugin INACTIVE. Adding notice.");
            self::$admin_notices[] = sprintf(
                __('WooCommerce Integration requires the "%s" plugin to be active for full functionality. The settings page is available, but integration features are disabled.', 'wc-minichat-addon'),
                'WooCommerce'
            );
            self::$dependencies_met = false;
        } else {
            error_log("WC Addon Log: check_dependencies() - Both Core and WC are ACTIVE.");
            self::$dependencies_met = true;
        }
        error_log("WC Addon Log: check_dependencies() finished.");
    }

    public static function load_textdomain() {
        error_log("WC Addon Log: load_textdomain() called.");
        load_plugin_textdomain('wc-minichat-addon', false, basename(dirname(__FILE__)) . '/languages');
        error_log("WC Addon Log: load_textdomain() finished.");
    }

    public static function load_files() {
        error_log("WC Addon Log: load_files() called.");
        // Only load files if the core plugin is active (settings page needs this)
        if (!self::$core_plugin_active) {
            error_log("WC Addon Log: load_files() - Core not active, returning.");
            return;
        }

        // Load the file responsible for the admin page and settings registration
        $admin_page_file = WC_MINICHAT_ADDON_PATH . 'includes/admin-page-wc-settings.php';
        error_log("WC Addon Log: load_files() - Checking admin file: " . $admin_page_file);
        if (file_exists($admin_page_file)) {
            error_log("WC Addon Log: load_files() - Admin file exists. Requiring: " . $admin_page_file);
            require_once $admin_page_file;
            error_log("WC Addon Log: load_files() - Required admin file successfully.");
        } else {
             error_log("WC Addon Log: load_files() - ERROR - Admin file NOT FOUND: " . $admin_page_file);
             self::$admin_notices[] = __('Error: Could not load the admin page file for WooCommerce Chatbot Integration.', 'wc-minichat-addon');
        }

        // Load the core integration logic ONLY if ALL dependencies are met
        if (self::$dependencies_met) {
            error_log("WC Addon Log: load_files() - Dependencies met, attempting to load integration logic.");
            // Lade die Logik aus dem includes-Verzeichnis
            $integration_file = WC_MINICHAT_ADDON_PATH . 'includes/woocommerce-integration.php';
            error_log("WC Addon Log: load_files() - Checking integration file: " . $integration_file);
            if (file_exists($integration_file)) {
                 error_log("WC Addon Log: load_files() - Integration file exists. Requiring: " . $integration_file);
                 require_once $integration_file;
                 error_log("WC Addon Log: load_files() - Required integration file successfully.");
            } else {
                 error_log("WC Addon Log: load_files() - ERROR - Integration file NOT FOUND: " . $integration_file);
                 self::$admin_notices[] = __('Error: Could not load the integration logic file (includes/woocommerce-integration.php) for WooCommerce Chatbot Integration.', 'wc-minichat-addon');
                 self::$dependencies_met = false; // Disable functionality if file missing
            }
        } else {
             error_log("WC Addon Log: load_files() - Dependencies not met, skipping integration logic load.");
        }
        error_log("WC Addon Log: load_files() finished.");
    }

    public static function add_admin_menu() {
        error_log("WC Addon Log: add_admin_menu() called.");
        // Only add the menu if the core plugin is active
        if (!self::$core_plugin_active) {
             error_log("WC Addon Log: add_admin_menu() - Core not active, returning.");
            return;
        }

        // Check if the required rendering function exists (loaded in load_files)
        if (!function_exists('minichat_wc_addon_render_settings_page')) {
            error_log("WC Addon Log: add_admin_menu() - ERROR - Rendering function 'minichat_wc_addon_render_settings_page' not found.");
            self::$admin_notices[] = __('Could not add WooCommerce Chatbot Integration menu item because its rendering function is missing.', 'wc-minichat-addon');
            return;
        }
        error_log("WC Addon Log: add_admin_menu() - Rendering function found.");

        $page_title = __('Chatbot WooCommerce Integration', 'wc-minichat-addon');
        $menu_title = __('Chatbot Integration', 'wc-minichat-addon');
        $capability = 'manage_woocommerce';

        // Fallback capability and permission check
         if (!current_user_can($capability)) {
             error_log("WC Addon Log: add_admin_menu() - User cannot manage_woocommerce, checking manage_options.");
             $capability = 'manage_options';
         }
         if (!current_user_can($capability)) {
             error_log("WC Addon Log: add_admin_menu() - User lacks capability ('" . $capability . "'), returning.");
             return;
         }
         error_log("WC Addon Log: add_admin_menu() - User has capability: " . $capability);

        $menu_slug = WC_MINICHAT_ADDON_PAGE_SLUG;
        $callback = 'minichat_wc_addon_render_settings_page';

        if (self::$woocommerce_active) {
            error_log("WC Addon Log: add_admin_menu() - Adding submenu under 'woocommerce'.");
            add_submenu_page(
                'woocommerce',
                $page_title,
                $menu_title,
                $capability,
                $menu_slug,
                $callback,
                3
            );
        } else {
            error_log("WC Addon Log: add_admin_menu() - Adding submenu under 'minimal-chatbot-settings' (fallback).");
            $core_menu_slug = 'minimal-chatbot-settings';

            global $submenu;
            if (isset($submenu[$core_menu_slug])) {
                 add_submenu_page(
                    $core_menu_slug,
                    $page_title,
                    __('WC Integration', 'wc-minichat-addon'),
                    $capability,
                    $menu_slug,
                    $callback
                );
                 error_log("WC Addon Log: add_admin_menu() - Fallback submenu added successfully.");
            } else {
                 error_log('WC Addon Log: add_admin_menu() - ERROR - Could not find parent menu slug ' . $core_menu_slug . ' for fallback.');
                 self::$admin_notices[] = __('Could not add WC Integration menu under Minimal Chatbot menu.', 'wc-minichat-addon');
            }
        }
        error_log("WC Addon Log: add_admin_menu() finished.");
    }


    public static function enqueue_frontend_assets() {
        error_log("WC Addon Log: enqueue_frontend_assets() called.");
        // Only enqueue if all dependencies are met AND the integration is enabled in settings
        $integration_enabled = get_option('minichat_wc_integration_enabled', false);
        if (!self::$dependencies_met || !$integration_enabled) {
             $reason = !self::$dependencies_met ? 'Dependencies not met' : 'Integration disabled';
             error_log("WC Addon Log: enqueue_frontend_assets() - Skipping enqueue. Reason: " . $reason);
            return;
        }

        // Also check if the core script handle exists and is enqueued
        if (!wp_script_is('minichat-scripts', 'enqueued')) {
             error_log("WC Addon Log: enqueue_frontend_assets() - Core script 'minichat-scripts' not enqueued, skipping add-on assets.");
            return;
        }
        error_log("WC Addon Log: enqueue_frontend_assets() - Core script found. Enqueuing add-on assets.");

        // Enqueue Add-on CSS
        wp_enqueue_style(
            'wc-minichat-addon-styles',
            WC_MINICHAT_ADDON_URL . 'assets/wc-chatbot-addon.css',
            ['minichat-styles'],
            WC_MINICHAT_ADDON_VERSION
        );
        error_log("WC Addon Log: enqueue_frontend_assets() - Enqueued CSS: wc-minichat-addon-styles");

        // Enqueue Add-on JS
        wp_enqueue_script(
            'wc-minichat-addon-script',
            WC_MINICHAT_ADDON_URL . 'assets/wc-chatbot-addon.js',
            ['jquery', 'minichat-scripts'],
            WC_MINICHAT_ADDON_VERSION,
            true // Load in footer
        );
         error_log("WC Addon Log: enqueue_frontend_assets() - Enqueued JS: wc-minichat-addon-script");
         error_log("WC Addon Log: enqueue_frontend_assets() finished.");
    }

    public static function display_admin_notices() {
        // No need to log inside here, gets called frequently.
        if (!empty(self::$admin_notices)) {
            foreach (self::$admin_notices as $notice) {
                ?>
                <div class="notice notice-warning is-dismissible">
                    <p><strong><?php esc_html_e('WooCommerce Chatbot Integration:', 'wc-minichat-addon'); ?></strong> <?php echo wp_kses_post($notice); ?></p>
                </div>
                <?php
            }
        }
    }

}
error_log("WC Addon Log: Class WC_Minichat_Addon defined.");

// Initialize the Add-on
error_log("WC Addon Log: Calling WC_Minichat_Addon::init().");
WC_Minichat_Addon::init();
error_log("WC Addon Log: Called WC_Minichat_Addon::init(). End of file.");

?>